#!/usr/bin/env python

# Load ESDS
import esds
import numpy as np

########## Scenario ##########
# Notations:
#   - Remaining communication duration (last communication ends minus current simulated time) = C
#   - Last communication duration (previous row) = U
#   - Last remaining data size (previous row) = D
#   - Current remaining data (current row) = R
#   - Initial data size (first row) = I
#   - Bandwidth = BW
#   - Latency = L
# |-------------------+------------+----------------+----------------------+---------------------------+--------------------------|
# | Simulated time(s) | Latency(s) | Bandwidth(bps) | Remaining data (bit) | Communication duration(s) | Communication ends at(s) |
# |-------------------+------------+----------------+----------------------+---------------------------+--------------------------|
# |                 0 |          0 |              8 | 8                    | 1                         |                        1 |
# |               0.5 |          0 |             16 | C/U*D = 4            | R/I * L + R/BW = 0.25     |                     0.75 |
# |              0.75 |          0 |             16 |                      |                           |                          |
# |-------------------+------------+----------------+----------------------+---------------------------+--------------------------|
##############################

B=np.full((2,2),8)
L=np.full((2,2),0)
s=esds.Simulator({"wlan0":{"bandwidth":B, "latency":L, "is_wired":False}, "eth0":{"bandwidth":B, "latency":L, "is_wired":True}})

s.create_node("sender")
s.create_node("receiver")

def callback(simulator):
    simulator.log("Network update!")
    new_bw_wlan0=simulator.netmat["wlan0"]["bandwidth"]*2
    new_bw_eth0=simulator.netmat["eth0"]["bandwidth"]*2
    simulator.update_network({"wlan0":{"bandwidth":new_bw_wlan0, "latency":L, "is_wired":False}, "eth0":{"bandwidth":new_bw_eth0, "latency":L, "is_wired":True}})

s.run(breakpoints_every=1/2,breakpoint_callback=callback)
